--/***************** BEGIN FILE HRADER BLOCK *********************************
--*
--* \author Ning hualong <ninghualong@yy.com> phone:15013359003
--*
--* Copyright (C) 2017-2019 YY.Inc
--* All rights reserved.
--*
--* This library is free software; you can redistribute it and/or modify it
--* under the terms of the GNU Lesser General Public License as published by
--* the Free Software Foundation; either version 3 of the License, or (at
--* your option) any later version. Please review the following information
--* to ensure the GNU Lesser General Public License version 3 requirements
--* will be met: https://www.gnu.org/licenses/lgpl.html.
--*
--* You should have received a copy of the GNU Lesser General Public License
--* along with this library; if not, write to the Free Software Foundation.
--*
--* If you use the source in a your project, please consider send an e-mail
--* to me, and allow me to add your project to my home page.
--*
--***************** END FILE HRADER BLOCK ***********************************/
TAG = "OrangeFilter-BrightnessFilter"
OF_LOGI(TAG, "Call BrightnessFilter lua script!")

local vs = [[
precision highp float;
attribute vec4 aPosition;
attribute vec4 aTextureCoord;
varying vec2 vTexCoord;
 
void main()
{
    gl_Position = aPosition;
    vTexCoord = aTextureCoord.xy;
}
]]

local fs = [[
precision mediump float;
varying vec2 vTexCoord;
uniform sampler2D uTexture;
 
uniform float uBrightness;
 
 void main()
 {
     vec4 textureColor = texture2D(uTexture, vTexCoord);
     
     gl_FragColor = vec4((textureColor.rgb + vec3(uBrightness)), textureColor.w);
 }
]]

local _brightnessPass = nil


function initParams(context, filter)
	OF_LOGI(TAG, "call initParams")
    filter:insertFloatParam("Brightness", -1.0, 1.0, 0.0)

	return OF_Result_Success
end

function initRenderer(context, filter)
	OF_LOGI(TAG, "call initRenderer")
	_brightnessPass = context:createCustomShaderPass(vs, fs)
	return OF_Result_Success
end

function teardownRenderer(context, filter)
	OF_LOGI(TAG, "call teardownRenderer")
	context:destroyCustomShaderPass(_brightnessPass)
	return OF_Result_Success
end

function applyRGBA(context, filter, frameData, inTex, outTex, debugTex)

	context:setViewport(0, 0, outTex.width, outTex.height)
	context:setBlend(false)
	context:bindFBO(outTex)
	_brightnessPass:use()
	_brightnessPass:setUniformTexture("uTexture", 0, inTex.textureID, GL_TEXTURE_2D)
    _brightnessPass:setUniform1f("uBrightness", filter:floatParam("Brightness"))

	local quadRender = context:sharedQuadRender()
	quadRender:draw(_brightnessPass, false)

	if debugTex ~= nil then
		context:copyTexture(inTex, debugTex)
	end
	return OF_Result_Success
end

function requiredFrameData(context, game)
	return { OF_RequiredFrameData_None }
end

function onApplyParams(context, filter)
	OF_LOGI(TAG, "call onApplyParams")
	return OF_Result_Success
end

function readObject(context, filter, archiveIn)
	OF_LOGI(TAG, "call readObject")
	return OF_Result_Success
end

function writeObject(context, filter, archiveOut)
	OF_LOGI(TAG, "call writeObject")
	return OF_Result_Success
end